import { Ref } from 'vue';
import { BundledTheme } from 'shiki';
/**
 * The return type of the `useHighlighter` function.
 */
interface UseHighlighterReturn {
    highlightedCode: Ref<string>;
    highlightCode: (codeContent: string, themes: {
        light: BundledTheme;
        dark: BundledTheme;
    }) => Promise<void>;
}
/**
 * Custom hook to use the Shiki highlighter for syntax highlighting code content.
 *
 * @returns {Object} An object containing:
 * - `highlightedCode`: A ref that holds the highlighted HTML string.
 * - `highlightCode`: A function to highlight the provided code content based on the specified themes.
 */
export declare function useHighlighter(): UseHighlighterReturn;
/**
 * Normalizes quotes in strings that contain nested or mismatched double quotes due to JSON-stringify by replacing the outer double quotes with single quotes.
 *
 * @param {string} input - The input string that may contain nested or mismatched double quotes.
 * @returns {string} - The modified string with the outermost double quotes replaced by single quotes.
 */
export declare function normalizeQuotes(input: string): string;
/**
 * Observes changes to the preview-content element and executes scripts within it.
 */
export declare function executeScriptsTick(): void;
export {};
